==> glom-0.8.2.tar.bz2: glom-0.8.2/glom/mode_data/box_data_list_related.h <==
/* Glom
 *
 * Copyright (C) 2001-2004 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef BOX_DATA_LIST_RELATED_H
#define BOX_DATA_LIST_RELATED_H

#include "box_data_list.h"

class Box_Data_List_Related : public Box_Data_List
{
public: 
  Box_Data_List_Related();
  virtual ~Box_Data_List_Related();

  virtual void init_db_details(const Glib::ustring& strDatabaseName, const Relationship& relationship, const Gnome::Gda::Value& foreign_key_value,  const Gnome::Gda::Value& from_table_primary_key_value);

  virtual Glib::ustring get_KeyField() const;

  sigc::signal<void, Gnome::Gda::Value> signal_record_added;

protected:
  virtual void fill_from_database(); //Override.

  virtual void on_AddDel_user_added(const Gtk::TreeModel::iterator& row); //Override.
  virtual void on_record_added(const Gnome::Gda::Value& primary_key_value); //Override. Not a signal handler.

  virtual void enable_buttons();
  
protected:
  Glib::ustring m_strKeyField;
  Gnome::Gda::Value m_key_value;
};

#endif

==> glom-0.8.6.tar.bz2: glom-0.8.6/glom/mode_data/box_data_list_related.h <==
/* Glom
 *
 * Copyright (C) 2001-2004 Murray Cumming
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef BOX_DATA_LIST_RELATED_H
#define BOX_DATA_LIST_RELATED_H

#include "box_data_list.h"

class Box_Data_List_Related : public Box_Data_List
{
public: 
  Box_Data_List_Related();
  virtual ~Box_Data_List_Related();

  virtual void init_db_details(const Glib::ustring& strDatabaseName, const Relationship& relationship, const Gnome::Gda::Value& foreign_key_value,  const Gnome::Gda::Value& from_table_primary_key_value);

  virtual Glib::ustring get_KeyField() const;

  sigc::signal<void, Gnome::Gda::Value> signal_record_added;

protected:
  virtual void fill_from_database(); //Override.

  virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row); //Override.
  virtual void on_record_added(const Gnome::Gda::Value& primary_key_value); //Override. Not a signal handler.

  virtual void enable_buttons();
  
protected:
  Glib::ustring m_strKeyField;
  Gnome::Gda::Value m_key_value;
};

#endif
